@@ -8,7 +8,7 @@ use LWP::UserAgent;
 use URI;
 use JSON;
 
-our $VERSION = '1.0.1'; # VERSION
+our $VERSION = '1.0.2'; # VERSION
 
 =head1 NAME
 
@@ -16,7 +16,7 @@ WebService::GarminConnect - Access data from Garmin Connect
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 SYNOPSIS
 
@@ -221,9 +221,7 @@ Joel Loudermilk, C<< <jlouder at cpan.org> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-webservice-garminconnect at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebService-GarminConnect>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to L<https://github.com/jlouder/garmin-connect-perl/issues>.
 
 
 
